# remirepo/Fedora spec file for php-zendframework-zend-router
#
# Copyright (c) 2016-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    e2151a72e9d00b1962c26469bab50db66cf7ef14
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zendframework
%global gh_project   zend-router
%global php_home     %{_datadir}/php
%global library      Router
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_owner}-%{gh_project}
Version:        3.2.1
Release:        1%{?dist}
Summary:        Zend Framework %{library} component

Group:          Development/Libraries
License:        BSD
URL:            https://zendframework.github.io/%{gh_project}/
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.6
BuildRequires:  php-pcre
BuildRequires:  php-spl
BuildRequires: (php-composer(container-interop/container-interop) >= 1.2    with php-composer(container-interop/container-interop) < 2)
BuildRequires: (php-autoloader(%{gh_owner}/zend-http)             >= 2.8.1  with php-autoloader(%{gh_owner}/zend-http)             < 3)
BuildRequires: (php-autoloader(%{gh_owner}/zend-servicemanager)   >= 2.7.7  with php-autoloader(%{gh_owner}/zend-servicemanager)   < 4)
BuildRequires: (php-autoloader(%{gh_owner}/zend-stdlib)           >= 2.7.7  with php-autoloader(%{gh_owner}/zend-stdlib)           < 4)
# From composer, "require-dev": {
#        "phpunit/phpunit": "^5.7.22 || ^6.4.1",
#        "zendframework/zend-coding-standard": "~1.0.0",
#        "zendframework/zend-i18n": "^2.7.4"
BuildRequires: (php-autoloader(%{gh_owner}/zend-i18n)             >= 2.6    with php-autoloader(%{gh_owner}/zend-i18n)             < 3)
%global phpunit %{_bindir}/phpunit6
BuildRequires:  phpunit6 >= 6.4.3
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "container-interop/container-interop": "^1.2",
#        "zendframework/zend-http": "^2.8.1",
#        "zendframework/zend-servicemanager": "^2.7.8 || ^3.3",
#        "zendframework/zend-stdlib": "^2.7.7 || ^3.1"
Requires:       php(language) >= 5.6
%if ! %{bootstrap}
Requires:      (php-composer(container-interop/container-interop) >= 1.2    with php-composer(container-interop/container-interop) < 2)
Requires:      (php-autoloader(%{gh_owner}/zend-http)             >= 2.8.1  with php-autoloader(%{gh_owner}/zend-http)             < 3)
Requires:      (php-autoloader(%{gh_owner}/zend-servicemanager)   >= 2.7.7  with php-autoloader(%{gh_owner}/zend-servicemanager)   < 4)
Requires:      (php-autoloader(%{gh_owner}/zend-stdlib)           >= 2.7.7  with php-autoloader(%{gh_owner}/zend-stdlib)           < 4)
# From composer, "suggest": {
#        "zendframework/zend-i18n": "^2.6, if defining translatable HTTP path segments"
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 8
Suggests:       php-autoloader(%{gh_owner}/zend-i18n)
%endif
# From composer, "conflict": {
#        "zendframework/zend-mvc": "<3.0.0"
Conflicts:      php-composer(%{gh_owner}/zend-mvc)                <  3
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 2.5.1
Requires:       php-pcre
Requires:       php-spl

Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
zend-router provides flexible HTTP routing.

Routing currently works against the zend-http request and responses,
and provides capabilities around:

* Literal path matches
* Path segment matches (at path boundaries, and optionally validated
  using regex)
* Regular expression path matches
* HTTP request scheme
* HTTP request method
* Hostname

Additionally, it supports combinations of different route types in tree
structures, allowing for fast, b-tree lookups.

Documentation: https://zendframework.github.io/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE


%build
: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/Interop/Container/autoload.php',
    '%{php_home}/Zend/Http/autoload.php',
    '%{php_home}/Zend/ServiceManager/autoload.php',
    '%{php_home}/Zend/Stdlib/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/Zend/I18n/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{php_home}/Zend/
cp -pr src %{buildroot}%{php_home}/Zend/%{library}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/Zend/%{library}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZendTest\\%{library}\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in "php %{phpunit}" php70 php71 php72 php73; do
  if which $cmdarg; then
    set $cmdarg
    $1 -d memory_limit=1G ${2:-%{_bindir}/phpunit6} --verbose || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/Zend/%{library}


%changelog
* Mon Feb 11 2019 Remi Collet <remi@remirepo.net> - 3.2.1-1
- update to 3.2.1

* Mon Aug 20 2018 Remi Collet <remi@remirepo.net> - 3.2.0-1
- update to 3.2.0
- raise dependency on zendframework/zend-http 2.8.1

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0
- raise dependency on PHP 5.6
- raise dependency on container-interop/container-interop 1.2
- raise dependency on zendframework/zend-http 2.6
- raise dependency on zendframework/zend-servicemanager 2.7.8
- raise dependency on zendframework/zend-stdlib 2.7.7
- use range dependencies

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Dec  9 2017 Remi Collet <remi@remirepo.net> - 3.0.2-5
- switch from zend-loader to fedora/autoloader

* Tue Oct 24 2017 Remi Collet <remi@fedoraproject.org> - 3.0.2-4
- fix FTBFS from Koschei, add patch for PHP 7.2 from
  https://github.com/zendframework/zend-router/pull/39

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Jun 29 2016 Remi Collet <remi@fedoraproject.org> - 3.0.2-1
- update to 3.0.2

* Tue Apr 19 2016 Remi Collet <remi@fedoraproject.org> - 3.0.1-1
- initial package

